using System;
using System.IO;
using Server.Gumps;
using Server.Guilds;
using Server.Network;

namespace Server.Items
{
	public class Guildstone : Item
	{
		private Guild m_Guild;

		public Guild Guild
		{
			get
			{
				return m_Guild;
			}
		}

		public Guildstone( Guild g ) : base( 0xED4 )
		{
			m_Guild = g;

			Movable = false;
		}

		public Guildstone( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 1 ); // version

			writer.Write( m_Guild );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();

			switch ( version )
			{
				case 1:
				{
					m_Guild = reader.ReadGuild();

					goto case 0;
				}
				case 0:
				{
					break;
				}
			}

			if ( m_Guild == null )
				this.Delete();
		}

		public override void OnSingleClick( Mobile from )
		{
			this.LabelTo( from, 1041429 ); // a guldstone

			string name;

			if ( m_Guild == null )
			{
				name = "(unfounded)";
			}
			else if ( (name = m_Guild.Name) == null || (name = name.Trim()).Length <= 0 )
			{
				name = "(unnamed)";
			}

			this.LabelTo( from, name );
		}

		public override void OnDoubleClick( Mobile from )
		{
			if ( m_Guild == null )
			{
				Delete();
			}
			else if ( !from.InRange( GetWorldLocation(), 2 ) )
			{
				from.SendLocalizedMessage( 500446 ); // That is too far away.
			}
			else if ( m_Guild.Accepted.Contains( from ) )
			{
				m_Guild.Accepted.Remove( from );
				m_Guild.AddMember( from );

				GuildGump.EnsureClosed( from );
				from.SendGump( new GuildGump( from, m_Guild ) );
			}
			else if ( !m_Guild.IsMember( from ) )
			{
				from.Send( new MessageLocalized( Serial, ItemID, MessageType.Regular, 0x3B2, 3, 501158, "", "" ) ); // You are not a member ...
			}
			else
			{
				GuildGump.EnsureClosed( from );
				from.SendGump( new GuildGump( from, m_Guild ) );
			}
		}
	}
}