using System;
using Server.Targeting;
using Server.Network;

namespace Server.Spells.Second
{
	public class HarmSpell : Spell
	{
		private static SpellInfo m_Info = new SpellInfo(
				"Harm", "An Mani",
				SpellCircle.Second,
				212,
				9041,
				Reagent.Nightshade,
				Reagent.SpidersSilk
			);

		public HarmSpell( Mobile caster, Item scroll ) : base( caster, scroll, m_Info )
		{
		}

		public override void OnCast()
		{
			Caster.Target = new InternalTarget( this );
		}

		public void Target( Mobile m )
		{
			if ( !Caster.CanSee( m ) )
			{
				Caster.SendLocalizedMessage( 500237 ); // Target can not be seen.
			}
			else if ( CheckHSequence( m ) )
			{
				SpellHelper.Turn( Caster, m );

				SpellHelper.CheckReflect( (int)this.Circle, Caster, ref m );

				double damage = Utility.Random( 1, 15 );

				if ( CheckResisted( m ) )
				{
					damage *= 0.75;

					m.SendLocalizedMessage( 501783 ); // You feel yourself resisting magical energy.
				}

				damage *= GetDamageScalar( m );

				int xRelative = Caster.X - m.X;
				int yRelative = Caster.Y - m.Y;
				double distanceScalar = Math.Sqrt( (xRelative * xRelative) + (yRelative * yRelative) );

				distanceScalar /= 10.0;

				distanceScalar = 1.0 - distanceScalar;

				if ( distanceScalar <= 0.0 )
					damage = 0.0;
				else if ( distanceScalar < 1.0 )
					damage *= distanceScalar;

				Effects.SendTargetParticles( m, 0x374A, 10, 15, 5013, EffectLayer.Waist );
				m.PlaySound( 0x1F1 );

				SpellHelper.Damage( this, m, damage );
			}

			FinishSequence();
		}

		private class InternalTarget : Target
		{
			private HarmSpell m_Owner;

			public InternalTarget( HarmSpell owner ) : base( 12, false, TargetFlags.Harmful )
			{
				m_Owner = owner;
			}

			protected override void OnTarget( Mobile from, object o )
			{
				if ( o is Mobile )
				{
					m_Owner.Target( (Mobile)o );
				}
			}

			protected override void OnTargetFinish( Mobile from )
			{
				m_Owner.FinishSequence();
			}
		}
	}
}